@@ -1,6 +1,6 @@
 # Copyright (C) 2003-2009 by Dr. Dieter Maurer, Illtalstr. 25, D-66571 Bubach, Germany
 # see "LICENSE.txt" for details
-#       $Id: ManagableIndex.py,v 1.4 2009/10/16 13:28:38 dieter Exp $
+#       $Id: ManagableIndex.py,v 1.5 2009/10/17 05:38:27 dieter Exp $
 '''Managable Index abstract base class.'''
 
 import copy
@@ -130,6 +130,8 @@ class ManagableIndex(OFolder,Normalize, Ignore):
         if k not in allowed: raise ValueError('not a known property: %s' % k)
       obj.manage_changeProperties(**values)
     if extra:
+      # GenericSetup passes something stupid -- try to normalize
+      if not hasattr(extra, 'keys'): extra = extra.__dict__
       setProperties(self, extra, ('ValueProviders',))
       providers = extra.get('ValueProviders')
     else: providers = None
